@@ -1,5 +1,5 @@
 #!/usr/bin/env python
 from wfuzz.wfuzz import main_filter
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main_filter()
