@@ -2,5 +2,5 @@
 
 from wfuzz.wfuzz import main
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
