@@ -4,6 +4,7 @@
 
 # Python 2 and 3
 import sys
+
 if sys.version_info >= (3, 0):
     from urllib.parse import urlparse
     from urllib.parse import urlunparse
@@ -11,7 +12,6 @@ else:
     from urlparse import urlparse
     from urlparse import urlunparse
 
-import string
 import re
 import pycurl
 
@@ -19,7 +19,8 @@ from .Variables import VariablesSet
 from .exceptions import ReqRespException
 from .Response import Response
 
-from wfuzz.utils import python2_3_convert_to_unicode
+from wfuzz.helpers.str_func import python2_3_convert_to_unicode
+from wfuzz.helpers.obj_dic import CaseInsensitiveDict
 
 from .TextParser import TextParser
 
@@ -31,10 +32,10 @@ if not hasattr(pycurl, "PATH_AS_IS"):
 
 class Request:
     def __init__(self):
-        self.__host = None                        # www.google.com:80
-        self.__path = None                        # /index.php
-        self.__params = None                      # Mierdaza de index.php;lskjflkasjflkasjfdlkasdf?
-        self.schema = "http"                      # http
+        self.__host = None  # www.google.com:80
+        self.__path = None  # /index.php
+        self.__params = None  # Mierdaza de index.php;lskjflkasjflkasjfdlkasdf?
+        self.schema = "http"  # http
 
         # #### Variables calculadas por getters NO SE PUEDEN MODIFICAR
         # self.urlWithoutPath                    # http://www.google.es
@@ -46,7 +47,9 @@ class Request:
         # self.postdata=""              # Datos por POST, toto el string
         # ###############
 
-        self.ContentType = "application/x-www-form-urlencoded"      # None es normal encoding
+        self.ContentType = (
+            "application/x-www-form-urlencoded"  # None es normal encoding
+        )
         self.multiPOSThead = {}
 
         self.__variablesGET = VariablesSet()
@@ -54,26 +57,28 @@ class Request:
         self._non_parsed_post = None
 
         # diccionario, por ejemplo headers["Cookie"]
-        self._headers = {
-            'Content-Type': 'application/x-www-form-urlencoded',
-            "User-Agent": "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1)"
-        }
+        self._headers = CaseInsensitiveDict(
+            {
+                "Content-Type": "application/x-www-form-urlencoded",
+                "User-Agent": "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1)",
+            }
+        )
 
-        self.response = None              # Apunta a la response que produce dicha request
+        self.response = None  # Apunta a la response que produce dicha request
 
         # ################## lo de debajo no se deberia acceder directamente
 
-        self.time = None                  # 23:00:00
-        self.ip = None                    # 192.168.1.1
+        self.time = None  # 23:00:00
+        self.ip = None  # 192.168.1.1
         self._method = None
-        self.protocol = "HTTP/1.1"        # HTTP/1.1
+        self.protocol = "HTTP/1.1"  # HTTP/1.1
         self.__performHead = ""
         self.__performBody = ""
 
         self.__authMethod = None
         self.__userpass = ""
 
-        self.description = ""     # For temporally store imformation
+        self.description = ""  # For temporally store imformation
 
         self.__proxy = None
         self.proxytype = None
@@ -106,9 +111,9 @@ class Request:
     def __str__(self):
         str = "[ URL: %s" % (self.completeUrl)
         if self.postdata:
-            str += " - {}: \"{}\"".format(self.method, self.postdata)
+            str += ' - {}: "{}"'.format(self.method, self.postdata)
         if "Cookie" in self._headers:
-            str += " - COOKIE: \"%s\"" % self._headers["Cookie"]
+            str += ' - COOKIE: "%s"' % self._headers["Cookie"]
         str += " ]"
         return str
 
@@ -134,11 +139,22 @@ class Request:
 
     def __getattr__(self, name):
         if name == "urlWithoutVariables":
-            return urlunparse((self.schema, self.__host, self.__path, '', '', ''))
+            return urlunparse((self.schema, self.__host, self.__path, "", "", ""))
         elif name == "pathWithVariables":
-            return urlunparse(('', '', self.__path, '', self.__variablesGET.urlEncoded(), ''))
+            return urlunparse(
+                ("", "", self.__path, "", self.__variablesGET.urlEncoded(), "")
+            )
         elif name == "completeUrl":
-            return urlunparse((self.schema, self.__host, self.__path, self.__params, self.__variablesGET.urlEncoded(), ''))
+            return urlunparse(
+                (
+                    self.schema,
+                    self.__host,
+                    self.__path,
+                    self.__params,
+                    self.__variablesGET.urlEncoded(),
+                    "",
+                )
+            )
         elif name == "finalUrl":
             if self.__finalurl:
                 return self.__finalurl
@@ -152,7 +168,7 @@ class Request:
                 return self._variablesPOST.urlEncoded()
             elif self.ContentType == "multipart/form-data":
                 return self._variablesPOST.multipartEncoded()
-            elif self.ContentType == 'application/json':
+            elif self.ContentType == "application/json":
                 return self._variablesPOST.json_encoded()
             else:
                 return self._variablesPOST.urlEncoded()
@@ -161,14 +177,16 @@ class Request:
 
     def setUrl(self, urltmp):
         self.__variablesGET = VariablesSet()
-        self.schema, self.__host, self.__path, self.__params, variables, f = urlparse(urltmp)
+        self.schema, self.__host, self.__path, self.__params, variables, f = urlparse(
+            urltmp
+        )
         if "Host" not in self._headers or (not self._headers["Host"]):
             self._headers["Host"] = self.__host
 
         if variables:
             self.__variablesGET.parseUrlEncoded(variables)
 
-# ############## PROXY ##################################
+    # ############## PROXY ##################################
     def getProxy(self):
         return self.__proxy
 
@@ -176,11 +194,11 @@ class Request:
         self.__proxy = prox
         self.proxytype = ptype
 
-# ############## FOLLOW LOCATION ########################
+    # ############## FOLLOW LOCATION ########################
     def setFollowLocation(self, value):
         self.followLocation = value
 
-# ############# TIMEOUTS ################################
+    # ############# TIMEOUTS ################################
     def setConnTimeout(self, time):
         self.__timeout = time
 
@@ -193,7 +211,7 @@ class Request:
     def getTotalTimeout(self):
         return self.__totaltimeout
 
-# ############# Autenticacion ###########################
+    # ############# Autenticacion ###########################
     def setAuth(self, method, string):
         self.__authMethod = method
         self.__userpass = string
@@ -201,7 +219,7 @@ class Request:
     def getAuth(self):
         return self.__authMethod, self.__userpass
 
-# ############# TRATAMIENTO VARIABLES GET & POST #########################
+    # ############# TRATAMIENTO VARIABLES GET & POST #########################
 
     def existsGETVar(self, key):
         return self.__variablesGET.existsVar(key)
@@ -212,7 +230,8 @@ class Request:
     def setVariablePOST(self, key, value):
         v = self._variablesPOST.getVariable(key)
         v.update(value)
-#       self._headers["Content-Length"] = str(len(self.postdata))
+
+    #       self._headers["Content-Length"] = str(len(self.postdata))
 
     def setVariableGET(self, key, value):
         v = self.__variablesGET.getVariable(key)
@@ -231,7 +250,7 @@ class Request:
         try:
             if self.ContentType == "multipart/form-data":
                 self._variablesPOST.parseMultipart(pd, boundary)
-            elif self.ContentType == 'application/json':
+            elif self.ContentType == "application/json":
                 self._variablesPOST.parse_json_encoded(pd)
             else:
                 self._variablesPOST.parseUrlEncoded(pd)
@@ -242,21 +261,18 @@ class Request:
                 print("Warning: POST parameters not parsed")
                 pass
 
-############################################################################
+    ############################################################################
 
     def addHeader(self, key, value):
-        k = string.capwords(key, "-")
-        self._headers[k] = value
+        self._headers[key] = value
 
     def delHeader(self, key):
-        k = string.capwords(key, "-")
-        if k in self._headers:
-            del self._headers[k]
+        if key in self._headers:
+            del self._headers[key]
 
     def __getitem__(self, key):
-        k = string.capwords(key, "-")
-        if k in self._headers:
-            return self._headers[k]
+        if key in self._headers:
+            return self._headers[key]
         else:
             return ""
 
@@ -282,7 +298,7 @@ class Request:
         self.response = rp
 
     def createPath(self, newpath):
-        '''Creates new url from a location header || Hecho para el followLocation=true'''
+        """Creates new url from a location header || Hecho para el followLocation=true"""
         if "http" in newpath[:4].lower():
             return newpath
 
@@ -290,7 +306,7 @@ class Request:
         if "/" != newpath[0]:
             newpath = "/".join(parts[2].split("/")[:-1]) + "/" + newpath
 
-        return urlunparse([parts[0], parts[1], newpath, '', '', ''])
+        return urlunparse([parts[0], parts[1], newpath, "", "", ""])
 
     # pycurl - reqresp conversions
     @staticmethod
@@ -347,7 +363,9 @@ class Request:
             c.setopt(pycurl.CUSTOMREQUEST, req.method)
 
         if req._non_parsed_post is not None:
-            c.setopt(pycurl.POSTFIELDS, python2_3_convert_to_unicode(req._non_parsed_post))
+            c.setopt(
+                pycurl.POSTFIELDS, python2_3_convert_to_unicode(req._non_parsed_post)
+            )
 
         c.setopt(pycurl.FOLLOWLOCATION, 1 if req.followLocation else 0)
 
@@ -394,8 +412,15 @@ class Request:
     # ######## ESTE conjunto de funciones no es necesario para el uso habitual de la clase
 
     def getAll(self):
-        pd = self._non_parsed_post if self._non_parsed_post else ''
-        string = str(self.method) + " " + str(self.pathWithVariables) + " " + str(self.protocol) + "\n"
+        pd = self._non_parsed_post if self._non_parsed_post else ""
+        string = (
+            str(self.method)
+            + " "
+            + str(self.pathWithVariables)
+            + " "
+            + str(self.protocol)
+            + "\n"
+        )
         for i, j in self._headers.items():
             string += i + ": " + j + "\n"
         string += "\n" + pd
@@ -418,16 +443,16 @@ class Request:
         self.parseRequest(b, self.schema)
 
     def parseRequest(self, rawRequest, prot="http"):
-        ''' Aun esta en fase BETA y por probar'''
+        """ Aun esta en fase BETA y por probar"""
         tp = TextParser()
         tp.setSource("string", rawRequest)
 
         self._variablesPOST = VariablesSet()
-        self._headers = {}                # diccionario, por ejemplo headers["Cookie"]
+        self._headers = {}  # diccionario, por ejemplo headers["Cookie"]
 
         tp.readLine()
         try:
-            tp.search(r"^(\w+) (.*) (HTTP\S*)$")
+            tp.search(r"^(\S+) (.*) (HTTP\S*)$")
             self.method = tp[0][0]
             self.protocol = tp[0][2]
         except Exception as a:
@@ -435,12 +460,12 @@ class Request:
             raise a
 
         pathTMP = tp[0][1].replace(" ", "%20")
-        pathTMP = ('', '') + urlparse(pathTMP)[2:]
+        pathTMP = ("", "") + urlparse(pathTMP)[2:]
         pathTMP = urlunparse(pathTMP)
 
         while True:
             tp.readLine()
-            if (tp.search("^([^:]+): (.*)$")):
+            if tp.search("^([^:]+): (.*)$"):
                 self.addHeader(tp[0][0], tp[0][1])
             else:
                 break
@@ -448,7 +473,7 @@ class Request:
         self.setUrl(prot + "://" + self._headers["Host"] + pathTMP)
 
         # ignore CRLFs until request line
-        while tp.lastline == '' and tp.readLine():
+        while tp.lastline == "" and tp.readLine():
             pass
 
         # TODO: hacky, might need to change tp.readline returning read bytes instead
